pub struct RoutingCode {
pub value: u32,
}Expand description
In the old Lotus, LINE and ROUTE were used for the information that the vehicle sent to the route balises.
The vehicle then sent these values to the ITCS server.
In the future, we want to reduce this to a kind of train control number.
Nothing will change for conventional IBIS devices for the time being.
Together with a planned additional text field in the FIS file, these train control numbers
should be adjustable per line and route.
This will also allow alternative train control devices to be supported and
direction-based traffic light requests to be achieved in the future.
(However, this is still a long way off and is more of a preliminary step at this stage.)
This is a mandatory message. Ultimately, however, the vehicle must also decide
whether it supports this type of request at all.
Fields
value: u32Trait Implementations
Sourceimpl Clone for RoutingCode
impl Clone for RoutingCode
Sourcefn clone(&self) -> RoutingCode
fn clone(&self) -> RoutingCode
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for RoutingCode
impl Debug for RoutingCode
Sourceimpl<'de> Deserialize<'de> for RoutingCode
impl<'de> Deserialize<'de> for RoutingCode
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl MessageType for RoutingCode
impl MessageType for RoutingCode
Sourceconst MESSAGE_META: MessageMeta
const MESSAGE_META: MessageMeta
Sourceimpl PartialEq for RoutingCode
impl PartialEq for RoutingCode
Sourceimpl Serialize for RoutingCode
impl Serialize for RoutingCode
impl StructuralPartialEq for RoutingCode