DoorControlTarget

Enum DoorControlTarget 

pub enum DoorControlTarget {
    Closed,
    Released(DoorSide),
    Open(DoorSide),
}
Now, we come to the door status information. Two different messages were used here in the previous Lotus. One is ATBUSSTOP (integer) and the other is DOORSOPEN (integer). We now want to merge these. This will no longer only contain the information ‘door release’ yes/no, but also the status of whether the doors have generally been opened and on which side the doors are released/opened.

As with the other messages before, this information is NOT transmitted via the coupling so that the door side is not twisted in the case of asymmetrically coupled vehicles. Of course, there can also be several circuits here, e.g. in buses for the front end and the rear end. It is only important that all modules receive this information once.

Variants



Closed



Released(DoorSide)



Open(DoorSide)