PowerSignalState

Enum PowerSignalState 

pub enum PowerSignalState {
    On {
        quickstart: bool,
        cabin_id: PowerSignalCabin,
    },
    Off {
        cabin_id: PowerSignalCabin,
    },
}
This message will replace and extend the old message MAINSWITCH (integer). We want to extend the information content as follows. Firstly, for each switch-on/switch-off message there is information on where the status has just been changed. For example, central on-board computers that are technically included in an IBIS terminal can also switch on and off correctly. The values ACab and BCab indicate whether one of the two driver’s cabs has been activated in the respective vehicle. With the NoCab status, the modules in the attached wagons also receive the information that a driver’s cab has now been activated in the train set. The other change is a Boolean parameter in the switch-on message. This can be used to transmit the ‘Quickstart’ command (value = true). As a result, modules should skip the boot process and run directly in steady operation. One of the advantages of this is that you don’t have to wait for long start procedures when debugging the module and it also ensures that the module is directly available in the active driver’s cab if the ‘Place vehicle’ start option ‘Ready to drive’ is selected. Previously, you had to cheat a little here.

The included information about the driver’s cab means that this message is also sent directly to all modules (and the driver’s own vehicle) via broadcast. The possibility of modules knowing in future which driver’s cab they belong to means that they can react appropriately. The message is also NOT transmitted via the coupling and must be generated independently by each vehicle for its modules. Here, the default status is switched off for all objects, too.

Variants



On

Fields

quickstart: bool


Off

Fields

Implementations

Source

impl PowerSignalState

pub fn is_on(&self) -> bool

pub fn is_off(&self) -> bool