pub struct PowerSetting(pub f32);Expand description
Passing a power setting value to a mechanical component (e.g. throttle valve in a combustion engine). Value generally ranges from 0.0 to 1.0, 1.0 corresponds to the maximum normal setting value. Values above 1.0 are also conceivable if technically possible.
Important: The target component can process this value in a control loop, but this is by no means necessarily the case!
Tuple Fields
0: f32Trait Implementations
Sourceimpl Clone for PowerSetting
impl Clone for PowerSetting
Sourcefn clone(&self) -> PowerSetting
fn clone(&self) -> PowerSetting
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PowerSetting
impl Debug for PowerSetting
Sourceimpl<'de> Deserialize<'de> for PowerSetting
impl<'de> Deserialize<'de> for PowerSetting
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl MessageType for PowerSetting
impl MessageType for PowerSetting
Sourceconst MESSAGE_META: MessageMeta
const MESSAGE_META: MessageMeta
The metadata for the message type.
Sourceimpl PartialEq for PowerSetting
impl PartialEq for PowerSetting
Sourceimpl Serialize for PowerSetting
impl Serialize for PowerSetting
impl Copy for PowerSetting
impl StructuralPartialEq for PowerSetting