StopRequest

Struct StopRequest 

pub struct StopRequest {
    pub value: bool,
}
The broadcast STOPREQUEST (single) was previously used here. In our proposal, the function is retained, only the data type is changed to Boolean.

As with the previous messages, this is NOT transmitted via the coupler. However, it should otherwise reach all modules in the vehicle. If there are several stop request circuits in a vehicle (e.g. a bus in the front vehicle and in the rear vehicle), messages can of course be sent with different receivers. Vehicles without a stop request (e.g. historic trains or underground trains) do not have to provide this information.

Fields

value: bool