RoutingCode

Struct RoutingCode 

pub struct RoutingCode {
    pub value: u32,
}
In the old Lotus, LINE and ROUTE were used for the information that the vehicle sent to the route balises. The vehicle then sent these values to the ITCS server. In the future, we want to reduce this to a kind of train control number. Nothing will change for conventional IBIS devices for the time being. Together with a planned additional text field in the FIS file, these train control numbers should be adjustable per line and route. This will also allow alternative train control devices to be supported and direction-based traffic light requests to be achieved in the future. (However, this is still a long way off and is more of a preliminary step at this stage.) This is a mandatory message. Ultimately, however, the vehicle must also decide whether it supports this type of request at all.

Fields

value: u32