pub struct StopRequest {
pub value: bool,
}Expand description
The broadcast STOPREQUEST (single) was previously used here. In our proposal, the function is retained,
only the data type is changed to Boolean.
As with the previous messages, this is NOT transmitted via the coupler. However, it should otherwise reach all modules in the vehicle. If there are several stop request circuits in a vehicle (e.g. a bus in the front vehicle and in the rear vehicle), messages can of course be sent with different receivers. Vehicles without a stop request (e.g. historic trains or underground trains) do not have to provide this information.
Fields
value: boolTrait Implementations
Sourceimpl Clone for StopRequest
impl Clone for StopRequest
Sourcefn clone(&self) -> StopRequest
fn clone(&self) -> StopRequest
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StopRequest
impl Debug for StopRequest
Sourceimpl<'de> Deserialize<'de> for StopRequest
impl<'de> Deserialize<'de> for StopRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl MessageType for StopRequest
impl MessageType for StopRequest
Sourceconst MESSAGE_META: MessageMeta
const MESSAGE_META: MessageMeta
The metadata for the message type.
Sourceimpl PartialEq for StopRequest
impl PartialEq for StopRequest
Sourceimpl Serialize for StopRequest
impl Serialize for StopRequest
impl StructuralPartialEq for StopRequest